import re
from dosage.modules.helpers.BasicComicModule import BasicComicModule
from dosage.util import getQueryParams

class Misfile(BasicComicModule):
    latestUrl = 'http://www.misfile.com/'
    imageUrl = 'http://www.misfile.com/?page=%s'
    imageSearch = re.compile(r'<img src="(overlay\.php\?pageCalled=\d+)">')
    prevSearch = re.compile(r'<a href="(\?page=\d+)"><img src="/images/back\.gif"')
    help = 'Index format: n (unpadded)'

    def getFilename(self, imageUrl, pageUrl):
        return getQueryParams(imageUrl)['pageCalled'][0]
